nagios_host 'journals.ametsoc.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'AMetSoc Home',
		'address' => 'journals.ametsoc.org',
		'contact_groups' => 'cs_escalation,ametsoc',
		'notes' => 'AMetSoc Live Site',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/AMETSOC/pages/936476697/Server+Setup+-+American+Meteorological+Society+AMetSoc'
end
nagios_host 'admin-journals.ametsoc.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'AMetSoc Admin',
		'address' => 'admin-journals.ametsoc.org',
		'contact_groups' => 'cs_escalation,ametsoc',
		'notes' => 'AMetSoc Production Management Portal',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/AMETSOC/pages/936476697/Server+Setup+-+American+Meteorological+Society+AMetSoc'
end
nagios_host 'ams-journals.ametsoc.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'AMetSoc AMS',
		'address' => 'ams-journals.ametsoc.org',
		'contact_groups' => 'cs_escalation,ametsoc',
		'notes' => 'AMetSoc Production AMS',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/AMETSOC/pages/936476697/Server+Setup+-+American+Meteorological+Society+AMetSoc'
end
#------------------------------------------------------------------------------------
# HOMEPAGE
# checks the homepage of the live AMetSoc site and checks for the string 'Meteorological'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Live Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Live Homepage',
		'check_command' => 'https_content_check_basic_auth!ametsoc:ametsoc2020!/!"Meteorological"!10!20!',
		'contact_groups' => 'cs_escalation,ametsoc',
		'notes' => 'AMetSoc Live Site',
		'notes_url' => 'https://journals.ametsoc.org'
end
#------------------------------------------------------------------------------------
# SEARCH
# Checks the search of the live AMetSoc site and checks for the string 'Search'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Live Search' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Live Search',
		'check_command' => 'https_content_check_basic_auth!ametsoc:ametsoc2020!/search!Search!10!20!',
		'contact_groups' => 'cs_escalation,ametsoc',
		'notes' => 'AMetSoc Live Site',
		'notes_url' => 'https://journals.ametsoc.org/search'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW
# checks the content view of the live AMetSoc site and checks for the string 'Meteorological'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Live content view' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Live content view',
		'check_command' => 'https_content_check_basic_auth!ametsoc:ametsoc2020!/jamc/issue/59/12!Meteorological!10!20!',
		'contact_groups' => 'cs_escalation,ametsoc',
		'notes' => 'AMetSoc Live Site',
		'notes_url' => 'https://journals.ametsoc.org/view/journals/2054/2054-overview.xml'
end
#------------------------------------------------------------------------------------
# LOADER
# Checks a loader login page and looks for the string 'Ametsoc PROD' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Production Loader' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'admin-journals.ametsoc.org',
		'display_name' => 'Production Loader',
		'check_command' => 'check_loader_auth!admin-journals.ametsoc.org!/login!ametsoc:ametsoc2020!"Ametsoc Production"!20!10',
		'contact_groups' => 'admins_email_only,ametsoc',
		'notes' => 'AMetSoc Live Loader',
		'notes_url' => 'https://admin-journals.ametsoc.org/login'
end
#------------------------------------------------------------------------------------
# STAGING
# Checks the staging site homepage and looks for the string 'Meteorological' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Staging Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Staging Homepage',
		'check_command' => 'check_staging_auth!staging-journals.ametsoc.org!ametsoc:ametsoc2020!"Meteorological"!20!10',
		'contact_groups' => 'admins_email_only,ametsoc',
		'notes' => 'AMetSoc Staging Site',
		'notes_url' => 'staging.journals.ametsoc.org'
end
#------------------------------------------------------------------------------------
# AMX
# Checks the production amx homepage and looks for the string 'AMS' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Production AMX' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ams-journals.ametsoc.org',
		'display_name' => 'Production AMX',
		'check_command' => 'check_loader_auth!ams-journals.ametsoc.org!/login!ametsoc:ametsoc2020!AMS!20!10',
		'contact_groups' => 'admins_email_only,ametsoc',
		'notes' => 'AMetSoc AMX',
		'notes_url' => 'https://ams-journals.ametsoc.org/login'
end
#------------------------------------------------------------------------------------
# FAIL OPEN
# Checks the production homepage and makes sure we're not in fail open by checking
# that the string "Provisional Account" is NOT in the page.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Live Site Fail Open' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Live Site Fail Open',
		'check_command' => 'http_negate_content_check_basic_auth!journals.ametsoc.org!ametsoc:ametsoc2020!"provisional account"',
		'contact_groups' => 'admins_email_only,ametsoc',
		'notes' => 'AMetSoc Live Site Failopen',
		'notes_url' => 'https://journals.ametsoc.org/'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 2)
# checks the homepage of the live ametsoc site on the first web node and checks for the string 'AMS'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Live Homepage: ametsoc-web-4' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Live Homepage: ametsoc-web-4',
		'check_command' => 'https_content_check_basic_auth_single_node!ametsoc:ametsoc2020!/!"AMS"!10!20!ametsoc-web-4-live!ametsoc-web-4.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,ametsoc',
		'notes' => 'AMETSOC Live Site: ametsoc-web-4',
		'notes_url' => 'https://journals.ametsoc.org'
end
#------------------------------------------------------------------------------------
# SEARCH (NODE 2)
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Live Search: ametsoc-web-4' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Live search: ametsoc-web-4',
		'check_command' => 'https_content_check_basic_auth_single_node!ametsoc:ametsoc2020!/search!Browse!10!20!ametsoc-web-4-live!ametsoc-web-4.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,ametsoc',
		'notes' => 'AMETSOC Live Site: ametsoc-web-4',
		'notes_url' => 'https://journals.ametsoc.org/search'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (NODE 2)
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Live content view: ametsoc-web-4' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Live content view: ametsoc-web-4',
		'check_command' => 'https_content_check_basic_auth_single_node!ametsoc:ametsoc2020!/view/journals/wcas/13/2/wcas-d-20-0107.1.xml!NWS!10!20!ametsoc-web-4-live!ametsoc-web-4.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,ametsoc',
		'notes' => 'AMETSOC Live Site: ametsoc-web-4',
		'notes_url' => 'https://journals.ametsoc.org/view/journals/wcas/13/2/wcas-d-20-0107.1.xml'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (Node 3)
# Checks the homepage of the live journals.ametsoc site on the bot web node and checks for the string 'AMS'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Live Homepage: ametsoc-webbot-1 bot node' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Live Homepage: ametsoc-webbot-1',
		'check_command' => 'https_content_check_basic_auth_single_node_bot!ametsoc:2020!/!AMS!10!20!ametsoc-webbot-1-live!ametsoc-webbot-1.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,ametsoc',
		'notes' => 'ametsoc Site: ametsoc-webbot-1',
		'notes_url' => 'https://journals.ametsoc.org/'
end
#------------------------------------------------------------------------------------
# SEARCH (NODE 3)
# Checks the search of the live journals.ametsoc site on the first bot web node and checks for the string 'Browse'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Live Search: ametsoc-webbot-1 bot node' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Live Search: ametsoc-webbot-1',
		'check_command' => 'https_content_check_basic_auth_single_node_bot!ametsoc:2020!/search!Browse!10!20!ametsoc-webbot-1-live!ametsoc-webbot-1.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,ametsoc',
		'notes' => 'ametsoc Site: ametsoc-webbot-1',
		'notes_url' => 'https://journals.ametsoc.org/view/journals/wcas/13/2/wcas-d-20-0107.1.xml'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (NODE 3)
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Live content view: ametsoc-webbot-1' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Live content view: ametsoc-webbot-1',
		'check_command' => 'https_content_check_basic_auth_single_node_bot!ametsoc:ametsoc2020!/view/journals/wcas/13/2/wcas-d-20-0107.1.xml!NWS!10!20!ametsoc-webbot-1-live!ametsoc-webbot-1.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,ametsoc',
		'notes' => 'AMETSOC Live Site: ametsoc-webbot-1',
		'notes_url' => 'https://journals.ametsoc.org/view/journals/tpmd/104/1/article-p5.xml'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 4)
# checks the homepage of the live ametsoc site on the first web node and checks for the string 'AMS'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Live Homepage: ametsoc-web-2' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Live Homepage: ametsoc-web-2',
		'check_command' => 'https_content_check_basic_auth_single_node!ametsoc:ametsoc2020!/!"AMS"!10!20!ametsoc-web-2-live!ametsoc-web-2.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,ametsoc',
		'notes' => 'AMETSOC Live Site: ametsoc-web-2',
		'notes_url' => 'https://journals.ametsoc.org'
end
#------------------------------------------------------------------------------------
# SEARCH (NODE 4)
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Live Search: ametsoc-web-2' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Live search: ametsoc-web-2',
		'check_command' => 'https_content_check_basic_auth_single_node!ametsoc:ametsoc2020!/search!Browse!10!20!ametsoc-web-2-live!ametsoc-web-2.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,ametsoc',
		'notes' => 'AMETSOC Live Site: ametsoc-web-2',
		'notes_url' => 'https://journals.ametsoc.org/search'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (NODE 4)
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Live content view: ametsoc-web-2' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Live content view: ametsoc-web-2',
		'check_command' => 'https_content_check_basic_auth_single_node!ametsoc:ametsoc2020!/view/journals/wcas/13/2/wcas-d-20-0107.1.xml!NWS!10!20!ametsoc-web-2-live!ametsoc-web-2.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,ametsoc',
		'notes' => 'AMETSOC Live Site: ametsoc-web-2',
		'notes_url' => 'https://journals.ametsoc.org/view/journals/wcas/13/2/wcas-d-20-0107.1.xml'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 5)
# checks the homepage of the live ametsoc site on the first web node and checks for the string 'AMS'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Live Homepage: ametsoc-web-1' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Live Homepage: ametsoc-web-1',
		'check_command' => 'https_content_check_basic_auth_single_node!ametsoc:ametsoc2020!/!"AMS"!10!20!ametsoc-web-1-live!ametsoc-web-1.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,ametsoc',
		'notes' => 'AMETSOC Live Site: ametsoc-web-1',
		'notes_url' => 'https://journals.ametsoc.org'
end
#------------------------------------------------------------------------------------
# SEARCH (NODE 5)
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Live Search: ametsoc-web-1' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Live search: ametsoc-web-1',
		'check_command' => 'https_content_check_basic_auth_single_node!ametsoc:ametsoc2020!/search!Browse!10!20!ametsoc-web-1-live!ametsoc-web-1.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,ametsoc',
		'notes' => 'AMETSOC Live Site: ametsoc-web-1',
		'notes_url' => 'https://journals.ametsoc.org/search'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (NODE 5)
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'journals.ametsoc.org-Live content view: ametsoc-web-1' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'journals.ametsoc.org',
		'display_name' => 'Live content view: ametsoc-web-1',
		'check_command' => 'https_content_check_basic_auth_single_node!ametsoc:ametsoc2020!/view/journals/wcas/13/2/wcas-d-20-0107.1.xml!NWS!10!20!ametsoc-web-1-live!ametsoc-web-1.irl.pubfactory.net!',
		'contact_groups' => 'admins_email_only,ametsoc',
		'notes' => 'AMETSOC Live Site: ametsoc-web-1',
		'notes_url' => 'https://journals.ametsoc.org/view/journals/wcas/13/2/wcas-d-20-0107.1.xml'
end
