nagios_host 'pubs.nctm.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'NCTM',
		'address' => 'pubs.nctm.org',
		'contact_groups' => 'cs_escalation,nctm',
		'notes' => 'NCTM Live Site',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/NCTM/pages/577830944/NCTM+-+Server+Setup'
end
nagios_host 'admin-pubs.nctm.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'NCTM',
		'address' => 'admin-pubs.nctm.org',
		'contact_groups' => 'cs_escalation,nctm',
		'notes' => 'NCTM Production Management Portal',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/NCTM/pages/577830944/NCTM+-+Server+Setup'
end
nagios_host 'ams-pubs.nctm.org' do
	options 'use' => 'noping-host-https',
		'alias' => 'NCTM',
		'address' => 'ams-pubs.nctm.org',
		'contact_groups' => 'cs_escalation,nctm',
		'notes' => 'NCTM Production AMS',
		'notes_url' => 'https://safari.atlassian.net/wiki/spaces/NCTM/pages/577830944/NCTM+-+Server+Setup'
end
#------------------------------------------------------------------------------------
# HOMEPAGE
# checks the homepage of the live NCTM site and checks for the string 'National Council of Teachers of Mathematics'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'pubs.nctm.org-Live Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'pubs.nctm.org',
		'display_name' => 'Live Homepage',
		'check_command' => 'https_content_check_basic_auth!nctm:nctm2018!/!NCTM!10!20!',
		'contact_groups' => 'cs_escalation,nctm',
		'notes' => 'NCTM Live Site',
		'notes_url' => 'https://pubs.nctm.org'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 1)
# checks the homepage of the live nctm site on the sercond web node and checks for the string 'National Council of Teachers of Mathematics'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'pubs.nctm.org-Live Homepage: nctm-web-4' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'pubs.nctm.org',
		'display_name' => 'Live Homepage: nctm-web-4',
		'check_command' => 'https_content_check_basic_auth_single_node!nctm:nctm2018!/!"National Council of Teachers of Mathematics"!10!20!nctm-web-live4!nctm-web-4!',
		'contact_groups' => 'admins_email_only,nctm',
		'notes' => 'NCTM Live Site: nctm-web-4',
		'notes_url' => 'https://pubs.nctm.org'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (NODE 2)
# checks the homepage of the live nctm site on the first web node and checks for the string 'National Council of Teachers of Mathematics'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'pubs.nctm.org-Live Homepage: nctm-web-3' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'pubs.nctm.org',
		'display_name' => 'Live Homepage: nctm-web-3',
		'check_command' => 'https_content_check_basic_auth_single_node!nctm:nctm2018!/!"National Council of Teachers of Mathematics"!10!20!nctm-web-live3!nctm-web-3!',
		'contact_groups' => 'admins_email_only,nctm',
		'notes' => 'NCTM Live Site: nctm-web-3',
		'notes_url' => 'https://pubs.nctm.org'
end
#------------------------------------------------------------------------------------
# HOMEPAGE (BOT NODE)
# checks the homepage of the live nctm site on the first web node and checks for the string 'National Council of Teachers of Mathematics'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'pubs.nctm.org-Live Homepage: nctm-webbot-2' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'pubs.nctm.org',
		'display_name' => 'Live Homepage: nctm-webbot-2',
		'check_command' => 'https_content_check_basic_auth_single_node_bot!nctm:nctm2018!/!"National Council of Teachers of Mathematics"!10!20!nctm-web-live-bot2!nctm-webbot-2!',
		'contact_groups' => 'admins_email_only,nctm',
		'notes' => 'NCTM Live Site: nctm-webbot-2',
		'notes_url' => 'https://pubs.nctm.org'
end
#------------------------------------------------------------------------------------
# SEARCH
# Checks the search of the live NCTM site and checks for the string 'National Council of Teachers of Mathematics'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'pubs.nctm.org-Live Search' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'pubs.nctm.org',
		'display_name' => 'Live Search',
		'check_command' => 'https_content_check_basic_auth!nctm:nctm2018!/browse!browse!10!20!',
		'contact_groups' => 'cs_escalation,nctm',
		'notes' => 'NCTM Live Site',
		'notes_url' => 'https://pubs.nctm.org/browse'
end
#------------------------------------------------------------------------------------
# SEARCH (NODE 1)
# Checks the search of the live nctm site on the second web node and checks for the string 'National Council of Teachers of Mathematics'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'pubs.nctm.org-Live Search: nctm-web-4' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'pubs.nctm.org',
		'display_name' => 'Live search: nctm-web-4',
		'check_command' => 'https_content_check_basic_auth_single_node!nctm:nctm2018!/browse!browse!10!20!nctm-web-live4!nctm-web-4!',
		'contact_groups' => 'admins_email_only,nctm',
		'notes' => 'NCTM Live Site: nctm-web-4',
		'notes_url' => 'https://pubs.nctm.org/browse'
end
#------------------------------------------------------------------------------------
# SEARCH (NODE 2)
# Checks the search of the live nctm site on the first web node and checks for the string 'National Council of Teachers of Mathematics'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'pubs.nctm.org-Live Search: nctm-web-3' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'pubs.nctm.org',
		'display_name' => 'Live search: nctm-web-3',
		'check_command' => 'https_content_check_basic_auth_single_node!nctm:nctm2018!/browse!browse!10!20!nctm-web-live3!nctm-web-3!',
		'contact_groups' => 'admins_email_only,nctm',
		'notes' => 'NCTM Live Site: nctm-web-3',
		'notes_url' => 'https://pubs.nctm.org/browse'
end
#------------------------------------------------------------------------------------
# SEARCH (BOT NODE)
# Checks the search of the live nctm site on the first web node and checks for the string 'National Council of Teachers of Mathematics'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'pubs.nctm.org-Live Search: nctm-webbot-2' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'pubs.nctm.org',
		'display_name' => 'Live search: nctm-webbot-2',
		'check_command' => 'https_content_check_basic_auth_single_node_bot!nctm:nctm2018!/browse!browse!10!20!nctm-web-live-bot2!nctm-webbot-2!',
		'contact_groups' => 'admins_email_only,nctm',
		'notes' => 'NCTM Live Site: nctm-webbot-2',
		'notes_url' => 'https://pubs.nctm.org/browse'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW
# checks the content view of the live NCTM site and checks for the string 'National Council of Teachers of Mathematics'.
#
# Node-specific: NO, Pager-level: YES
#------------------------------------------------------------------------------------
nagios_service 'pubs.nctm.org-Live content view' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'pubs.nctm.org',
		'display_name' => 'Live content view',
		'check_command' => 'https_content_check_basic_auth!nctm:nctm2018!/view/journals/jrme/51/1/article-p105_1.xml!Calculus!10!20!',
		'contact_groups' => 'cs_escalation,nctm',
		'notes' => 'NCTM Live Site',
		'notes_url' => 'hhttps://pubs.nctm.org/view/journals/jrme/51/1/article-p105_1.xml'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (NODE 1)
# checks the content view of the live nctm site on the sedmond web node and checks for the string 'National Council of Teachers of Mathematics'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'pubs.nctm.org-Live content view: nctm-web-4' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'pubs.nctm.org',
		'display_name' => 'Live content view: nctm-web-4',
		'check_command' => 'https_content_check_basic_auth_single_node!nctm:nctm2018!/view/journals/jrme/51/1/article-p105_1.xml!Calculus!10!20!nctm-web-live4!nctm-web-4!',
		'contact_groups' => 'admins_email_only,nctm',
		'notes' => 'NCTM Live Site: nctm-web-4',
		'notes_url' => 'https://pubs.nctm.org/view/journals/jrme/51/1/article-p105_1.xml'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (NODE 2)
# checks the content view of the live nctm site on the first web node and checks for the string 'National Council of Teachers of Mathematics'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'pubs.nctm.org-Live content view: nctm-web-3' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'pubs.nctm.org',
		'display_name' => 'Live content view: nctm-web-3',
		'check_command' => 'https_content_check_basic_auth_single_node!nctm:nctm2018!/view/journals/jrme/51/1/article-p105_1.xml!Calculus!10!20!nctm-web-live3!nctm-web-3!',
		'contact_groups' => 'admins_email_only,nctm',
		'notes' => 'NCTM Live Site: nctm-web-3',
		'notes_url' => 'https://pubs.nctm.org/view/journals/jrme/51/1/article-p105_1.xml'
end
#------------------------------------------------------------------------------------
# CONTENT VIEW (BOT NODE)
# checks the content view of the live nctm site on the first web node and checks for the string 'National Council of Teachers of Mathematics'.
#
# Node-specific: YES, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'pubs.nctm.org-Live content view: nctm-webbot-2' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'pubs.nctm.org',
		'display_name' => 'Live content view: nctm-webbot-2',
		'check_command' => 'https_content_check_basic_auth_single_node_bot!nctm:nctm2018!/view/journals/jrme/51/1/article-p105_1.xml!Calculus!10!20!nctm-web-live-bot2!nctm-webbot-2!',
		'contact_groups' => 'admins_email_only,nctm',
		'notes' => 'NCTM Live Site: nctm-webbot-2',
		'notes_url' => 'https://pubs.nctm.org/view/journals/jrme/51/1/article-p105_1.xml'
end
#------------------------------------------------------------------------------------
# LOADER
# Checks a loader login page and looks for the string 'Login' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'pubs.nctm.org-Production Loader' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'admin-pubs.nctm.org',
		'display_name' => 'Production Loader',
		'check_command' => 'check_loader_auth!admin-pubs.nctm.org!/login!nctm:nctm2018!"Nctm Production Management Portal"!20!10',
		'contact_groups' => 'admins_email_only,nctm',
		'notes' => 'NCTM Live Loader',
		'notes_url' => 'https://admin-pubs.nctm.org/login'
end
#------------------------------------------------------------------------------------
# STAGING
# Checks the staging site homepage and looks for the string 'National Council of Teachers of Mathematics' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'pubs.nctm.org-Staging Homepage' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'pubs.nctm.org',
		'display_name' => 'Staging Homepage',
		'check_command' => 'check_staging_auth!staging-pubs.nctm.org!nctm:nctm2018!"National Council of Teachers of Mathematics"!20!10',
		'contact_groups' => 'admins_email_only,nctm',
		'notes' => 'NCTM Staging Site',
		'notes_url' => 'https//staging-pubs.nctm.org'
end
#------------------------------------------------------------------------------------
# AMX
# Checks the production amx homepage and looks for the string 'AMS' in the response.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'pubs.nctm.org-Production AMX' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'ams-pubs.nctm.org',
		'display_name' => 'Production AMX',
		'check_command' => 'check_loader_auth!ams-pubs.nctm.org!/login!nctm:nctm2018!AMS!20!10',
		'contact_groups' => 'admins_email_only,nctm',
		'notes' => 'NCTM AMX',
		'notes_url' => 'https://ams-pubs.nctm.org/login'
end
#------------------------------------------------------------------------------------
# FAIL OPEN
# Checks the production homepage and makes sure we're not in fail open by checking
# that the string "Provisional Account" is NOT in the page.
#
# Node-specific: NO, Pager-level: NO
#------------------------------------------------------------------------------------
nagios_service 'pubs.nctm.org-Live Site Fail Open' do
	options 'use' => 'sbo-service-pf',
		'host_name' => 'pubs.nctm.org',
		'display_name' => 'Live Site Fail Open',
		'check_command' => 'http_negate_content_check_basic_auth!pubs.nctm.org!nctm:nctm2018!"provisional account"',
		'contact_groups' => 'admins_email_only,nctm',
		'notes' => 'NCTM Live Site Failopen',
		'notes_url' => 'https://pubs.nctm.org/'
end
